==> Guppi-0.34.5.tar.gz: Guppi-0.34.5/src/libguppidata/guppi-seq-integer-impl.h <==
/* This is -*- C -*- */
/* $Id: guppi-seq-integer-impl.h,v 1.1 2000/04/21 23:22:44 trow Exp $ */

/*
 * guppi-seq-integer-impl.h
 *
 * Copyright (C) 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org> and
 * Havoc Pennington <hp@pobox.com>.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef _INC_GUPPI_SEQ_INTEGER_IMPL_H
#define _INC_GUPPI_SEQ_INTEGER_IMPL_H

#include <config.h>
#include <gnome.h>

#include <guppi-seq-impl.h>

typedef struct _GuppiSeqIntegerImpl GuppiSeqIntegerImpl;
typedef struct _GuppiSeqIntegerImplClass GuppiSeqIntegerImplClass;

struct _GuppiSeqIntegerImpl {
  GuppiSeqImpl parent;
};

struct _GuppiSeqIntegerImplClass {
  GuppiSeqImplClass parent_class;

  /* Virtual functions */

  void (*range)(const GuppiSeqIntegerImpl*, gint* min, gint* max);
  gint (*frequency)(const GuppiSeqIntegerImpl*, gint);

  gint (*get)(const GuppiSeqIntegerImpl*, gint);
  void (*set)(GuppiSeqIntegerImpl*, gint i, gint val);
  void (*insert)(GuppiSeqIntegerImpl*, gint i, const gint* ptr, gsize N); 
};

#define GUPPI_TYPE_SEQ_INTEGER_IMPL (guppi_seq_integer_impl_get_type())
#define GUPPI_SEQ_INTEGER_IMPL(obj) (GTK_CHECK_CAST((obj),GUPPI_TYPE_SEQ_INTEGER_IMPL,GuppiSeqIntegerImpl))
#define GUPPI_SEQ_INTEGER_IMPL0(obj) ((obj) ? (GUPPI_SEQ_INTEGER_IMPL(obj)) : NULL)
#define GUPPI_SEQ_INTEGER_IMPL_CLASS(klass) (GTK_CHECK_CLASS_CAST((klass),GUPPI_TYPE_SEQ_INTEGER_IMPL,GuppiSeqIntegerImplClass))
#define GUPPI_IS_SEQ_INTEGER_IMPL(obj) (GTK_CHECK_TYPE((obj), GUPPI_TYPE_SEQ_INTEGER_IMPL))
#define GUPPI_IS_SEQ_INTEGER_IMPL0(obj) (((obj) == NULL) || (GUPPI_IS_SEQ_INTEGER_IMPL(obj)))
#define GUPPI_IS_SEQ_INTEGER_IMPL_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_SEQ_INTEGER_IMPL))

GtkType guppi_seq_integer_impl_get_type(void);

GtkObject* guppi_seq_integer_impl_new(void);



#endif /* _INC_GUPPI_SEQ_INTEGER_IMPL_H */

/* $Id: guppi-seq-integer-impl.h,v 1.1 2000/04/21 23:22:44 trow Exp $ */

==> Guppi-0.35.1.tar.gz: Guppi-0.35.1/src/libguppidata/guppi-seq-integer-impl.h <==
/* This is -*- C -*- */
/* $Id: guppi-seq-integer-impl.h,v 1.7 2000/10/27 18:22:58 trow Exp $ */

/*
 * guppi-seq-integer-impl.h
 *
 * Copyright (C) 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org> and
 * Havoc Pennington <hp@pobox.com>.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef _INC_GUPPI_SEQ_INTEGER_IMPL_H
#define _INC_GUPPI_SEQ_INTEGER_IMPL_H

#include <gtk/gtk.h>

#include <guppi-seq-impl.h>

#include <guppi-defs.h>

BEGIN_GUPPI_DECLS 

typedef struct _GuppiSeqIntegerImpl GuppiSeqIntegerImpl;

struct _GuppiSeqIntegerImpl {
  GuppiSeqImpl parent;
};

typedef struct {
  GuppiSeqImplClass parent_class;

  /* Virtual functions */

  void (*range) (const GuppiSeqIntegerImpl *, gint * min, gint * max);
    gint (*frequency) (const GuppiSeqIntegerImpl *, gint);

    gint (*get) (const GuppiSeqIntegerImpl *, gint);
  void (*set) (GuppiSeqIntegerImpl *, gint i, gint val);
  void (*insert) (GuppiSeqIntegerImpl *, gint i, const gint * ptr, gsize N);

} GuppiSeqIntegerImplClass;

#define GUPPI_TYPE_SEQ_INTEGER_IMPL (guppi_seq_integer_impl_get_type())
#define GUPPI_SEQ_INTEGER_IMPL(obj) (GTK_CHECK_CAST((obj),GUPPI_TYPE_SEQ_INTEGER_IMPL,GuppiSeqIntegerImpl))
#define GUPPI_SEQ_INTEGER_IMPL0(obj) ((obj) ? (GUPPI_SEQ_INTEGER_IMPL(obj)) : NULL)
#define GUPPI_SEQ_INTEGER_IMPL_CLASS(klass) (GTK_CHECK_CLASS_CAST((klass),GUPPI_TYPE_SEQ_INTEGER_IMPL,GuppiSeqIntegerImplClass))
#define GUPPI_IS_SEQ_INTEGER_IMPL(obj) (GTK_CHECK_TYPE((obj), GUPPI_TYPE_SEQ_INTEGER_IMPL))
#define GUPPI_IS_SEQ_INTEGER_IMPL0(obj) (((obj) == NULL) || (GUPPI_IS_SEQ_INTEGER_IMPL(obj)))
#define GUPPI_IS_SEQ_INTEGER_IMPL_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GUPPI_TYPE_SEQ_INTEGER_IMPL))

GtkType guppi_seq_integer_impl_get_type (void);

GtkObject *guppi_seq_integer_impl_new (void);


END_GUPPI_DECLS

#endif /* _INC_GUPPI_SEQ_INTEGER_IMPL_H */

/* $Id: guppi-seq-integer-impl.h,v 1.7 2000/10/27 18:22:58 trow Exp $ */
